valuedomain
    * ``auth_token`` Specify youyr api token


.. note::
   
   Value Domain requires a token to access its API.
   You can generate one for your account on the following URL:
   https://www.value-domain.com/vdapi/

